colour.colorimetry.dataset.illuminants.spds Module — Colour 0.3.0 documentation

# colour.colorimetry.dataset.illuminants.spds Module

## Illuminants Relative Spectral Power Distributions

Defines CIE illuminants relative spectral power distributions for the CIE 1931 2 Degree Standard Observer and CIE 1964 10 Degree Standard Observer.

The CIE illuminants data is in the form of a dict of `colour.colorimetry.spectrum.SpectralPowerDistribution` classes as follows:

    {'name': SpectralPowerDistribution, ..., 'name': SpectralPowerDistribution}

The following CIE illuminants are available:

- CIE Standard Illuminant A
- CIE Illuminant B
- CIE Illuminant C
- CIE Illuminant D Series (D50, D55, D60, D65, D75)
- CIE Illuminant E
- Illuminants F Series (F1, F10, F11, F12, F2, F3, F4, F5, F6, F7, F8, F9, FL3.1, FL3.10, FL3.11, FL3.12, FL3.13, FL3.14, FL3.15, FL3.2, FL3.3, FL3.4, FL3.5, FL3.6, FL3.7, FL3.8, FL3.9)
- High Pressure Discharge Lamps (HP1, HP2, HP3, HP4, HP5)

See also

Illuminants IPython Notebook

Notes

- The relative spectral power distributions are provided at 5 nm steps.
- CIE Illuminant D Series D60 relative spectral power distribution has been calculated using `colour.colorimetry.illuminants.D_illuminant_relative_spd()` definition.

References

[1] | http://files.cie.co.at/204.xls (Last accessed 24 February 2014)

[2] | https://law.resource.org/pub/us/cfr/ibr/003/cie.15.2004.tables.xls (Last accessed 24 February 2014)

[3] | http://onlinelibrary.wiley.com/store/10.1002/9781119975595.app5/asset/app5.pdf?v=1&t=hwc899dh&s=01d1e0b27764970185be52b69b4480f3305ddb6c

`colour.colorimetry.dataset.illuminants.spds.` `ILLUMINANTS_RELATIVE_SPDS` = CaseInsensitiveMapping({u'FL3.8': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8bd0>, u'FL3.9': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8c10>, u'D75': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8690>, u'FL3.2': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8a50>, u'FL3.3': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8a90>, u'FL3.1': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8a10>, u'FL3.6': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8b50>, u'FL3.7': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8b90>, u'FL3.4': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8ad0>, u'FL3.5': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8b10>, u'FL3.14': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8d50>, u'D50': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8590>, u'FL3.15': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8d90>, u'HP4': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8e90>, u'FL3.10': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8c50>, u'D55': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf85d0>, u'FL3.12': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8cd0>, u'FL3.13': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8d10>, u'HP3': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8e50>, u'HP2': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8e10>, u'HP1': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8dd0>, u'HP5': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8ed0>, u'FL3.11': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8c90>, u'A': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf84d0>, u'C': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8550>, u'B': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8510>, u'E': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf86d0>, u'F12': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf89d0>, u'F10': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8950>, u'F11': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8990>, u'D60': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8610>, u'D65': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8650>, u'F1': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8710>, u'F2': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8750>, u'F3': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8790>, u'F4': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf87d0>, u'F5': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8810>, u'F6': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8850>, u'F7': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8890>, u'F8': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf88d0>, u'F9': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8910>})

  CIE illuminants relative spectral power distributions.

  ILLUMINANTS_RELATIVE_SPDS : dict